==> handy_ui_kit-0.0.5.tar.gz: lib/src/MyDialog.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';

enum DialogType { success, error, warning }

class MyDialog extends StatefulWidget {
  final String title;
  final DialogType type;
  final String body;
  final String confirmText;
  final bool needDescription;
  final String descriptionLabel;
  final Widget extra;
  final double borderRadius;
  final EdgeInsets padding;

  const MyDialog(
      {Key key,
      @required this.title,
      this.type,
        @required this.body,
      this.confirmText,
      this.needDescription=false,
      this.extra,
      this.borderRadius = 12,
      this.padding = const EdgeInsets.all(8), this.descriptionLabel})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _MyDialogState();
  }
}

class _MyDialogState extends State<MyDialog> {
  TextEditingController msgController = TextEditingController();
  TextEditingController passController = TextEditingController();

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(widget.borderRadius),
      ),
      elevation: 0.0,
      backgroundColor: Colors.white,
      insetPadding: widget.padding,
      content: dialogContent(context),
      actions: widget.confirmText==null?
      <Widget>[
        FlatButton(child: Text("OK"),onPressed: ()=>Navigator.pop(context),)
      ]:<Widget>[
        FlatButton(child: Text("OK"),onPressed: ()=>Navigator.pop(context),),
        FlatButton(child: Text(widget.confirmText),onPressed: (){
          if (widget.needDescription) {
              Navigator.pop(context, msgController.text);
          } else {
            Navigator.pop(context, "---confirm---");
          }
        },)
      ],
    );
  }

  dialogContent(BuildContext context) {
    return _buildMainBody(context);
  }

  _buildHeader() {
    if (widget.type == DialogType.success) {
      return AssetImage('successHeader.png', package: 'handy_ui_kit');
    } else if (widget.type == DialogType.error) {
      return AssetImage('errorHeader.png', package: 'handy_ui_kit');
    } else {
      return AssetImage('alertHeader.png', package: 'handy_ui_kit');
    }
  }

  _buildMainBody(context) {
    return GestureDetector(
      onTap: () {
        FocusScope.of(context).requestFocus(new FocusNode());
      },
      child: Container(
        decoration: BoxDecoration(
          color: Colors.white,
          shape: BoxShape.rectangle,
          borderRadius: BorderRadius.circular(widget.borderRadius),
          boxShadow: [
            BoxShadow(
              color: Colors.black26,
              blurRadius: 10.0,
              offset: const Offset(0.0, 10.0),
            ),
          ],
        ),
        child: Column(
          mainAxisSize: MainAxisSize.min, // To make the card compact
          children: <Widget>[
            _buildHeader(),
            Container(
              margin: EdgeInsets.only(top: 10),
              child: Container(
                child: Column(
                  children: <Widget>[
                    Text(widget.title,style: TextStyle(fontWeight: FontWeight.bold),),
                    Text(widget.body),
                  ],
                ),
              ),
            ),
            widget.extra!=null?
                widget.extra:Container(),
            widget.needDescription
                ?_buildMsgField()
                : Container(),
          ],
        ),
      ),
    );
  }

  _buildMsgField() {
    return Container(
      padding: EdgeInsets.all(10),
      child: TextField(
        maxLines: null,
        controller: msgController,
        decoration: InputDecoration(
          hintText: widget.descriptionLabel,
          contentPadding: EdgeInsets.all(5),
          border: OutlineInputBorder(
            borderSide: BorderSide(color: Colors.teal),
          ),
        ),
      ),
    );
  }

}

==> handy_ui_kit-0.0.6.tar.gz: lib/src/MyDialog.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';

enum DialogType { success, error, warning }

class MyDialog extends StatefulWidget {
  final String title;
  final DialogType type;
  final String body;
  final String confirmText;
  final bool needDescription;
  final String descriptionLabel;
  final Widget extra;
  final double borderRadius;
  final EdgeInsets padding;

  const MyDialog(
      {Key key,
      @required this.title,
      this.type,
        @required this.body,
      this.confirmText,
      this.needDescription=false,
      this.extra,
      this.borderRadius = 12,
      this.padding = const EdgeInsets.all(8), this.descriptionLabel})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _MyDialogState();
  }
}

class _MyDialogState extends State<MyDialog> {
  TextEditingController msgController = TextEditingController();
  TextEditingController passController = TextEditingController();

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(widget.borderRadius),
      ),
      elevation: 0.0,
      backgroundColor: Colors.white,
      insetPadding: widget.padding,
      content: dialogContent(context),
      actions: widget.confirmText==null?
      <Widget>[
        FlatButton(child: Text("OK"),onPressed: ()=>Navigator.pop(context),)
      ]:<Widget>[
        FlatButton(child: Text("OK"),onPressed: ()=>Navigator.pop(context),),
        FlatButton(child: Text(widget.confirmText),onPressed: (){
          if (widget.needDescription) {
              Navigator.pop(context, msgController.text);
          } else {
            Navigator.pop(context, "---confirm---");
          }
        },)
      ],
    );
  }

  dialogContent(BuildContext context) {
    return _buildMainBody(context);
  }

  _buildHeader() {
    if (widget.type == DialogType.success) {
      return Image.asset('successHeader.png', package: 'handy_ui_kit');
    } else if (widget.type == DialogType.error) {
      return Image.asset('errorHeader.png', package: 'handy_ui_kit');
    } else {
      return Image.asset('alertHeader.png', package: 'handy_ui_kit');
    }
  }

  _buildMainBody(context) {
    return GestureDetector(
      onTap: () {
        FocusScope.of(context).requestFocus(new FocusNode());
      },
      child: Container(
        decoration: BoxDecoration(
          color: Colors.white,
          shape: BoxShape.rectangle,
          borderRadius: BorderRadius.circular(widget.borderRadius),
          boxShadow: [
            BoxShadow(
              color: Colors.black26,
              blurRadius: 10.0,
              offset: const Offset(0.0, 10.0),
            ),
          ],
        ),
        child: Column(
          mainAxisSize: MainAxisSize.min, // To make the card compact
          children: <Widget>[
            _buildHeader(),
            Container(
              margin: EdgeInsets.only(top: 10),
              child: Container(
                child: Column(
                  children: <Widget>[
                    Text(widget.title,style: TextStyle(fontWeight: FontWeight.bold),),
                    Text(widget.body),
                  ],
                ),
              ),
            ),
            widget.extra!=null?
                widget.extra:Container(),
            widget.needDescription
                ?_buildMsgField()
                : Container(),
          ],
        ),
      ),
    );
  }

  _buildMsgField() {
    return Container(
      padding: EdgeInsets.all(10),
      child: TextField(
        maxLines: null,
        controller: msgController,
        decoration: InputDecoration(
          hintText: widget.descriptionLabel,
          contentPadding: EdgeInsets.all(5),
          border: OutlineInputBorder(
            borderSide: BorderSide(color: Colors.teal),
          ),
        ),
      ),
    );
  }

}
